@@ -1,21 +1,14 @@
 import logging
 import urllib
+from xml.etree.ElementTree import fromstring
+
 import requests
 
-from lxml.etree import fromstring
-
-try:
-    from tvrenamr.errors import EmptyEpisodeNameException, \
-                                EpisodeNotFoundException, \
-                                NoNetworkConnectionException, \
-                                ShowNotFoundException, \
-                                XMLEmptyException
-except ImportError:
-    from . errors import EmptyEpisodeNameException, \
-                            EpisodeNotFoundException, \
-                            NoNetworkConnectionException, \
-                            ShowNotFoundException, \
-                            XMLEmptyException
+from tvrenamr.errors import (EmptyEpisodeNameException,
+                             EpisodeNotFoundException,
+                             NoNetworkConnectionException,
+                             ShowNotFoundException,
+                             XMLEmptyException)
 
 log = logging.getLogger('The Tv DB')
 
@@ -29,17 +22,17 @@ class TheTvDb():
         :param show_name: The show name of the episode title to be retrieved.
         """
         self.show = show
-        log.info('Searching: %s' % self.show)
         self.season = season
         self.episode = episode
 
-        self.show_id, self.show = self.__get_show_id()
+        log.info('Searching: %s' % self.show)
+        self.show_id, self.show = self._get_show_id()
         log.debug('Retrieved show id: %s' % self.show_id)
         log.debug('Retrieved canonical show name: %s' % self.show)
-        self.title = self.__get_episode_name()
+        self.title = self._get_episode_name()
         log.debug('Retrieved episode name: %s' % self.title)
 
-    def __get_show_id(self):
+    def _get_show_id(self):
         """
         Retrieves the show ID of the show name passed in when the class is instantiated.
 
@@ -76,7 +69,7 @@ class TheTvDb():
             else:
                 raise ShowNotFoundException(log.name, self.show)
 
-    def __get_episode_name(self):
+    def _get_episode_name(self):
         """
         Retrieves the episode title for the given episode from thetvdb.com.
 
